Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser.py	(revision 7459)
@@ -36,10 +36,10 @@
     SIRPPage, SIRPEditFormPage, SIRPAddFormPage, SIRPDisplayFormPage,
     ContactAdminForm, SIRPForm)
-from waeup.sirp.browser.interfaces import ICaptchaManager
+from waeup.sirp.browser.interfaces import ICaptchaManager, IBreadcrumbIgnorable
 from waeup.sirp.browser.breadcrumbs import Breadcrumb
 from waeup.sirp.browser.resources import datepicker, datatable, tabs, warning
 from waeup.sirp.browser.viewlets import (
     ManageActionButton, AddActionButton)
-from waeup.sirp.browser.layout import jsaction, JSAction
+from waeup.sirp.browser.layout import jsaction, action, UtilityView
 from waeup.sirp.interfaces import (
     ISIRPObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm,
@@ -64,4 +64,5 @@
 from waeup.sirp.applicants.interfaces import IApplicantBaseData
 from waeup.sirp.hostels.hostel import NOT_OCCUPIED
+from waeup.sirp.utils.helpers import get_current_principal
 
 def write_log_message(view, message):
@@ -96,4 +97,13 @@
     grok.context(IStudentsContainer)
     title = 'Students'
+    #grok.implements(IBreadcrumbIgnorable)
+
+    @property
+    def target(self):
+        user = get_current_principal()
+        #import pdb; pdb.set_trace()
+        if getattr(user, 'user_type', None) == 'student':
+            return None
+        return self.viewname
 
 class StudentBreadcrumb(Breadcrumb):
@@ -131,14 +141,4 @@
     grok.context(IStudentAccommodation)
     title = 'Accommodation'
-
-    #@property
-    #def target(self):
-    #    prm = get_principal_role_manager()
-    #    principal = get_current_principal()
-    #    roles = [x[0] for x in prm.getRolesForPrincipal(principal.id)]
-    #    if 'waeup.Student' in roles:
-    #        return 'index'
-    #    else:
-    #        return 'manage'
 
 class BedTicketBreadcrumb(Breadcrumb):
@@ -293,4 +293,6 @@
             if not self.hitlist:
                 self.flash('No student found.')
+            if 'remove' in form:
+                self.flash('No item selected.')
             return
         entries = form['entries']
@@ -328,5 +330,5 @@
     pnav = 4
 
-    @grok.action('Create student record')
+    @action('Create student record', style='primary')
     def addStudent(self, **data):
         student = createObject(u'waeup.Student')
@@ -383,5 +385,5 @@
         return u'Send message to %s' % self.context.display_fullname
 
-    @grok.action('Send message now')
+    @action('Send message now', style='primary')
     def send(self, *args, **data):
         try:
@@ -442,5 +444,5 @@
             dict(name=x, title=y) for x, y in allowed_transitions]
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         form = self.request.form
@@ -576,10 +578,10 @@
         return super(StudentClearanceManageFormPage, self).update()
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
         return
 
-class StudentClearPage(grok.View):
+class StudentClearPage(UtilityView, grok.View):
     """ Clear student by clearance officer
     """
@@ -600,5 +602,5 @@
         return
 
-class StudentRejectClearancePage(grok.View):
+class StudentRejectClearancePage(UtilityView, grok.View):
     """ Reject clearance by clearance officers
     """
@@ -662,5 +664,5 @@
     pnav = 4
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
@@ -732,5 +734,5 @@
         return 
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
@@ -744,5 +746,5 @@
             yield(dict(code=code, title=title))
 
-    @grok.action('Add study level')
+    @action('Add study level')
     def addStudyLevel(self, **data):
         level_code = self.request.form.get('addlevel', None)
@@ -754,4 +756,5 @@
         except KeyError:
             self.flash('This level exists.')
+        self.flash('Study level has been added.')
         self.redirect(self.url(self.context, u'@@manage')+'#tab-2')
         return
@@ -821,5 +824,5 @@
     target = 'course_registration.pdf'
 
-class ExportPDFCourseRegistrationSlipPage(grok.View):
+class ExportPDFCourseRegistrationSlipPage(UtilityView, grok.View):
     """Deliver a PDF slip of the context.
     """
@@ -921,10 +924,10 @@
         return 'Manage study level %s' % self.context.level_title
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
         return
 
-    @grok.action('Add course ticket')
+    @action('Add course ticket')
     def addCourseTicket(self, **data):
         self.redirect(self.url(self.context, '@@add'))
@@ -954,5 +957,5 @@
         return
 
-class ValidateCoursesPage(grok.View):
+class ValidateCoursesPage(UtilityView, grok.View):
     """ Validate course list by course adviser
     """
@@ -975,5 +978,5 @@
         return
 
-class RejectCoursesPage(grok.View):
+class RejectCoursesPage(UtilityView, grok.View):
     """ Reject course list by course adviser
     """
@@ -1022,5 +1025,5 @@
         return 'Study Level %s' % self.context.level_title
 
-    @grok.action('Add course ticket')
+    @action('Add course ticket')
     def addCourseTicket(self, **data):
         ticket = CourseTicket()
@@ -1046,5 +1049,5 @@
         return
 
-    @grok.action('Cancel')
+    @action('Cancel')
     def cancel(self, **data):
         self.redirect(self.url(self.context))
@@ -1095,5 +1098,5 @@
         return 'Manage course ticket %s' % self.context.code
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
@@ -1176,5 +1179,5 @@
         return
 
-    @grok.action('Add online payment ticket')
+    @action('Add online payment ticket')
     def addPaymentTicket(self, **data):
         self.redirect(self.url(self.context, '@@addop'))
@@ -1200,5 +1203,5 @@
     pnav = 4
     
-    @grok.action('Create ticket')
+    @action('Create ticket', style='primary')
     def createTicket(self, **data):
         p_category = data['p_category']
@@ -1296,5 +1299,5 @@
         return self.view.url(self.view.context, self.target)
 
-class OnlinePaymentCallbackPage(grok.View):
+class OnlinePaymentCallbackPage(UtilityView, grok.View):
     """ Callback view
     """
@@ -1345,5 +1348,5 @@
         return
 
-class ExportPDFPaymentSlipPage(grok.View):
+class ExportPDFPaymentSlipPage(UtilityView, grok.View):
     """Deliver a PDF slip of the context.
     """
@@ -1576,5 +1579,5 @@
     target = 'bed_allocation.pdf'
 
-class ExportPDFBedTicketSlipPage(grok.View):
+class ExportPDFBedTicketSlipPage(UtilityView, grok.View):
     """Deliver a PDF slip of the context.
     """
@@ -1608,5 +1611,5 @@
     target = 'relocate'
 
-class BedTicketRelocationPage(grok.View):
+class BedTicketRelocationPage(UtilityView, grok.View):
     """ Callback view
     """
@@ -1735,5 +1738,5 @@
     pnav = 4
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         msave(self, **data)
@@ -1751,5 +1754,5 @@
     pnav = 4
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         form = self.request.form
@@ -1898,5 +1901,5 @@
         return super(StudentClearanceEditFormPage, self).update()
 
-    @grok.action('Save')
+    @action('Save', style='primary')
     def save(self, **data):
         self.applyData(self.context, **data)
@@ -1911,5 +1914,5 @@
         return False
 
-    @grok.action('Save and request clearance')
+    @action('Save and request clearance', style='primary')
     def requestClearance(self, **data):
         self.applyData(self.context, **data)
@@ -2063,5 +2066,5 @@
         return
 
-    @grok.action('Create course list now')
+    @action('Create course list now', style='primary')
     def addStudyLevel(self, **data):
         studylevel = StudentStudyLevel()
@@ -2127,5 +2130,5 @@
         return total_credits
 
-    @grok.action('Add course ticket')
+    @action('Add course ticket')
     def addCourseTicket(self, **data):
         self.redirect(self.url(self.context, 'ctadd'))
@@ -2157,5 +2160,5 @@
         return
 
-    @grok.action('Register course list')
+    @action('Register course list', style='primary')
     def RegisterCourses(self, **data):
         IWorkflowInfo(self.context.getStudent()).fireTransition('register_courses')
@@ -2172,5 +2175,5 @@
         'grade', 'score', 'core_or_elective', 'automatic')
 
-    @grok.action('Add course ticket')
+    @action('Add course ticket')
     def addCourseTicket(self, **data):
         ticket = CourseTicket()
@@ -2211,5 +2214,5 @@
         return
 
-    @grok.action('Get login credentials')
+    @action('Get login credentials', style='primary')
     def request(self, **data):
         if not self.captcha_result.is_valid:
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/accommodationmanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/accommodationmanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/accommodationmanagepage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,5 +13,5 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data">
 
   <table class="display dataTableManage">
@@ -41,5 +41,5 @@
   </table>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <span tal:repeat="action view/selected_actions"
           tal:omit-tag="">
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basemanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basemanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basemanagepage.pt	(revision 7459)
@@ -4,7 +4,7 @@
 
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
-  <div class="form-status"
+  <div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -15,23 +15,21 @@
   </div>
 
-  <div id="tabs">
-    <ul>
-      <li><a href="#tab-1"><span>Base Data</span></a></li>
-      <li><a href="#tab-2"><span>Passport Picture</span></a></li>
-    </ul>
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active"><a href="#tab-1"><span>Base Data</span></a></li>
+    <li><a href="#tab-2"><span>Passport Picture</span></a></li>
+  </ul>
 
-    <div id="tab-1">
-      <table class="form-fields zebra">
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
         <tbody>
           <tal:block repeat="widget view/widgets">
             <tr>
-              <td class="label">
-                <label tal:attributes="for widget/name">
-                  <span class="required" tal:condition="widget/required">*</span>
-                  <span i18n:translate="" tal:content="widget/label">label</span>:
-                </label>
+              <td class="fieldname">
+                <span tal:condition="widget/required">*</span>
+                <span i18n:translate="" tal:content="widget/label">label</span>:
               </td>
-              <td class="field">
-                <span class="widget" tal:content="structure widget">
+              <td>
+                <span tal:content="structure widget">
                   <input type="text" />
                 </span>
@@ -40,5 +38,5 @@
                 </tal:error>
                 <tal:hint tal:condition="widget/hint">
-                  <span class="hint" tal:content="structure widget/hint">hint</span>
+                  <span tal:content="structure widget/hint">hint</span>
                 </tal:hint>
               </td>
@@ -46,5 +44,5 @@
           </tal:block>
           <tr>
-            <td class="label"><label>Password:</label></td>
+            <td class="fieldname">Password:</td>
             <td>
               <input name="password" type="password"  />
@@ -52,5 +50,5 @@
           </tr>
           <tr>
-            <td class="label"><label>Retype password:</label></td>
+            <td class="fieldname">Retype password:</td>
             <td>
               <input name="control_password" type="password" />
@@ -58,5 +56,5 @@
           </tr>
           <tr>
-            <td class="label"><label>Registration Transition:</label></td>
+            <td class="fieldname">Registration Transition:</td>
             <td>
               <select id="transition" name="transition">
@@ -72,5 +70,5 @@
       </table>
 
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <input tal:repeat="action view/actions"
                tal:replace="structure action/render"
@@ -80,6 +78,5 @@
 
     <div id="tab-2">
-      <h2>Upload passport picture</h2>
-      <table class="form-fields zebra">
+      <table class="form-table">
         <tbody>
           <tal:files content="structure provider:files" />
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/basepage.pt	(revision 7459)
@@ -3,5 +3,5 @@
     tal:content="view/label">Label</h2>
 
-<table class="zebra">
+<table class="form-table">
   <tbody>
     <tal:block repeat="widget view/widgets">
@@ -16,5 +16,5 @@
     </tal:block>
     <tr>
-      <td class="fieldname" width="33%">
+      <td class="fieldname">
           Password:
       </td>
@@ -26,6 +26,6 @@
   </tbody>
   <tfoot>
-    <tr class="controls">
-      <td colspan="2" class="align-right">
+    <tr>
+      <td>
         <input tal:repeat="action view/actions"
                tal:replace="structure action/render" />
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/change_password.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/change_password.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/change_password.pt	(revision 7459)
@@ -4,13 +4,13 @@
 
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
   <input type="hidden" name="student_id" value=""
          tal:attributes="value context/student_id" />
 
-  <table class="form-fields zebra">
+  <table class="form-table">
     <tbody>
       <tr>
-        <td class="label"><label>Password:</label></td>
+        <td class="fieldname">Password:</td>
         <td>
           <input name="change_password" type="password"  />
@@ -18,5 +18,5 @@
       </tr>
       <tr>
-        <td class="label"><label>Retype password:</label></td>
+        <td class="fieldname">Retype password:</td>
         <td>
           <input name="change_password_repeat" type="password" />
@@ -26,5 +26,5 @@
   </table>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <input tal:repeat="action view/actions"
            tal:replace="structure action/render"
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/changepw.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/changepw.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/changepw.pt	(revision 7459)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
   <h2 i18n:translate=""
@@ -6,5 +6,5 @@
     tal:content="view/label">Label</h2>
 
-  <div class="form-status"
+  <div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -15,16 +15,14 @@
   </div>
 
-  <table class="zebra">
+  <table class="form-table">
     <tbody>
       <tal:block repeat="widget view/widgets">
         <tr>
-          <td class="label">
-            <label tal:attributes="for widget/name">
-              <span class="required" tal:condition="widget/required">*</span>
+          <td class="fieldname">
+              <span tal:condition="widget/required">*</span>
               <span i18n:translate="" tal:content="widget/label">label</span>:
-            </label>
           </td>
-          <td class="field">
-            <span class="widget" tal:content="structure widget">
+          <td>
+            <span tal:content="structure widget">
               <input type="text" />
             </span>
@@ -33,5 +31,5 @@
             </tal:error>
             <tal:hint tal:condition="widget/hint">
-              <span class="hint" tal:content="structure widget/hint">hint</span>
+              <span tal:content="structure widget/hint">hint</span>
             </tal:hint>
           </td>
@@ -51,5 +49,5 @@
   </table>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <input tal:repeat="action view/actions"
            tal:replace="structure action/render"
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/clearanceeditpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/clearanceeditpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/clearanceeditpage.pt	(revision 7459)
@@ -4,7 +4,7 @@
 
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
-  <div class="form-status"
+  <div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -15,23 +15,20 @@
   </div>
 
-  <div id="tabs">
-    <ul>
-      <li><a href="#tab-1"><span>Clearance Data</span></a></li>
-      <li><a href="#tab-2"><span>Scans</span></a></li>
-    </ul>
-
-    <div id="tab-1">
-      <table class="form-fields zebra">
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active"><a href="#tab-1"><span>Clearance Data</span></a></li>
+    <li><a href="#tab-2"><span>Scans</span></a></li>
+  </ul>
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
         <tbody>
           <tal:block repeat="widget view/widgets">
             <tr>
-              <td class="label">
-                <label tal:attributes="for widget/name">
-                  <span class="required" tal:condition="widget/required">*</span>
+              <td class="fieldname">
+                  <span tal:condition="widget/required">*</span>
                   <span i18n:translate="" tal:content="widget/label">label</span>:
-                </label>
               </td>
-              <td class="field">
-                <span class="widget" tal:content="structure widget">
+              <td>
+                <span tal:content="structure widget">
                   <input type="text" />
                 </span>
@@ -40,5 +37,5 @@
                 </tal:error>
                 <tal:hint tal:condition="widget/hint">
-                  <span class="hint" tal:content="structure widget/hint">hint</span>
+                  <span tal:content="structure widget/hint">hint</span>
                 </tal:hint>
               </td>
@@ -48,5 +45,5 @@
       </table>
 
-      <div class="actionButtons" tal:condition="view/availableActions">
+      <div tal:condition="view/availableActions">
         <input tal:repeat="action view/actions"
                tal:replace="structure action/render"
@@ -56,6 +53,5 @@
 
     <div id="tab-2">
-      <h2>Upload scans</h2>
-      <table class="form-fields zebra">
+      <table class="form-table">
         <tbody>
           <tal:files content="structure provider:files" />
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containermanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containermanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containermanagepage.pt	(revision 7459)
@@ -4,5 +4,5 @@
 <br />
 
-  <input type="submit" name="search" value="Search" />
+  <input class="btn primary" type="submit" name="search" value="Search" />
   for students
 
@@ -48,8 +48,6 @@
     </table>
     
-    <div class="actionButtons">
-        <input type="submit" name="remove" value="Remove selected"
-               onclick="return confirmPost('Are you sure?')"/>
-    </div>
+    <input type="submit" name="remove" value="Remove selected" class="btn"
+           onclick="return confirmPost('Are you sure?')"/>
 
   </div>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containerpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containerpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/containerpage.pt	(revision 7459)
@@ -4,5 +4,5 @@
 <br />
 
-  <input type="submit" name="search" value="Search" />
+  <input class="btn primary" type="submit" name="search" value="Search" />
   for students
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketmanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketmanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketmanagepage.pt	(revision 7459)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
+      enctype="multipart/form-data">
 
   <h2 i18n:translate=""
@@ -6,5 +6,5 @@
     tal:content="view/label">Label</h2>
 
-  <div class="form-status"
+  <div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -15,6 +15,5 @@
   </div>
 
-
-  <table class="zebra">
+  <table class="form-table">
     <tbody>
       <tr>
@@ -68,12 +67,10 @@
       <tal:block repeat="widget view/widgets">
         <tr>
-          <td class="label">
-            <label tal:attributes="for widget/name">
-              <span class="required" tal:condition="widget/required">*</span>
+          <td class="fieldname">
+              <span tal:condition="widget/required">*</span>
               <span i18n:translate="" tal:content="widget/label">label</span>:
-            </label>
           </td>
-          <td class="field">
-            <span class="widget" tal:content="structure widget">
+          <td>
+            <span tal:content="structure widget">
               <input type="text" />
             </span>
@@ -82,5 +79,5 @@
             </tal:error>
             <tal:hint tal:condition="widget/hint">
-              <span class="hint" tal:content="structure widget/hint">hint</span>
+              <span tal:content="structure widget/hint">hint</span>
             </tal:hint>
           </td>
@@ -89,5 +86,5 @@
     </tbody>
   </table>
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <input tal:repeat="action view/actions"
            tal:replace="structure action/render"
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/courseticketpage.pt	(revision 7459)
@@ -3,5 +3,5 @@
     tal:content="view/label">Label</h2>
 
-<table class="zebra">
+<table class="form-table">
   <tbody>
     <tr>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/enterpin.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/enterpin.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/enterpin.pt	(revision 7459)
@@ -2,8 +2,8 @@
     tal:content="view/label">Label</h2>
 <form method="POST">
-  <table>
+  <table class="form-table">
     <tbody>
       <tr><td>
-        <label for="ac_series">Activation Code:</label>
+        Activation Code:
         </td><td>
         <span tal:replace="view/ac_prefix">PIN Prefix</span> -
@@ -18,7 +18,7 @@
       <tr>
         <td colspan="2">
-          <input type="submit" name="SUBMIT"
+          <input type="submit" name="SUBMIT" class="btn primary"
                  tal:attributes="value view/buttonname" />
-                 </td>
+        </td>
       </tr>
     </tbody>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filedisplay.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filedisplay.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filedisplay.pt	(revision 7459)
@@ -1,9 +1,7 @@
 <tr tal:condition = "viewlet/file_exists">
-  <td class="label">
-    <label i18n:translate="">
-        <span tal:replace="viewlet/label">FILENAME</span>:
-    </label>
+  <td class="fieldname">
+    <span tal:replace="viewlet/label">FILENAME</span>:
   </td>
-  <td class="field">
+  <td>
     <span class="widget">
       <a tal:attributes="href viewlet/download_name"
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filesuploadpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filesuploadpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/filesuploadpage.pt	(revision 7459)
@@ -4,6 +4,6 @@
 
 <form action="." tal:attributes="action request/URL" method="post"
-      class="edit-form" enctype="multipart/form-data">
-  <table class="zebra">
+      enctype="multipart/form-data">
+  <table class="form-table">
     <tbody>
       <tal:files content="structure provider:files" />
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/fileupload.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/fileupload.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/fileupload.pt	(revision 7459)
@@ -1,9 +1,7 @@
 <tr>
-  <td class="label">
-    <label i18n:translate="" tal:attributes="for viewlet/input_name">
-        <span tal:replace="viewlet/label">FILENAME</span>:
-    </label>
+  <td class="fieldname">
+    <span tal:replace="viewlet/label">FILENAME</span>:
   </td>
-  <td class="field">
+  <td>
     <span class="widget">
 
@@ -17,13 +15,13 @@
       <br />
       <input type="file" tal:attributes="name viewlet/input_name"/>
-      <br />
+      <br /><br />
       <input type="submit" tal:condition="viewlet/file_exists"
              tal:attributes="id python:('delete_%s' % viewlet.input_name);
                 name python:('delete_%s' % viewlet.input_name)"
-             value="Delete attachment" class="button" />
+             value="Delete attachment" class="btn error" />
       <input type="submit"
                tal:attributes="id python:('upload_%s' % viewlet.input_name);
                   name python:('upload_%s' % viewlet.input_name)"
-               value="Upload new file" class="button" />
+               value="Upload new file" class="btn primary" />
       <span i18n:translate="">
         Max. file size:
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imagedisplay.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imagedisplay.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imagedisplay.pt	(revision 7459)
@@ -1,13 +1,9 @@
 <tr>
-  <td class="label">
-    <label i18n:translate="">
+  <td class="fieldname">
         <span tal:replace="viewlet/label">FILENAME</span>:
-    </label>
   </td>
-  <td class="field">
-    <span class="widget">
+  <td>
       <img height="125px" tal:attributes="src viewlet/download_name" />
       <br />
-    </span>
   </td>
 </tr>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imageupload.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imageupload.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/imageupload.pt	(revision 7459)
@@ -1,9 +1,7 @@
 <tr>
-  <td class="label">
-    <label i18n:translate="" tal:attributes="for viewlet/input_name">
-        <span tal:replace="viewlet/label">FILENAME</span>:
-    </label>
+  <td class="fieldname">
+    <span tal:replace="viewlet/label">FILENAME</span>:
   </td>
-  <td class="field">
+  <td>
     <span class="widget">
       <img align="middle" height="125px"
@@ -12,11 +10,12 @@
        tal:attributes="id python:('delete_%s' % viewlet.input_name);
           name python:('delete_%s' % viewlet.input_name)"
-       value="Delete" class="button" />
+       value="Delete" class="btn error" />
       <br /><br />
       <input type="file" tal:attributes="name viewlet/input_name"/>
+      <br /><br />
       <input type="submit"
                tal:attributes="id python:('upload_%s' % viewlet.input_name);
                   name python:('upload_%s' % viewlet.input_name)"
-               value="Upload" class="button" />
+               value="Upload" class="btn primary" />
       <span i18n:translate="">
         Max. file size:
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt	(revision 7459)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/mydatadropdowntabs.pt	(revision 7459)
@@ -0,0 +1,9 @@
+<li tal:attributes="class viewlet/active" data-dropdown="dropdown" >
+  <a href="#" class="dropdown-toggle" tal:content="viewlet/tab_title">Tab Title</a>
+  <ul class="dropdown-menu">
+    <li tal:repeat="target viewlet/targets">
+      <a tal:attributes="href target/url"
+         tal:content="target/title">Link Title</a>
+    </li>
+  </ul>
+</li>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentsmanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentsmanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentsmanagepage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,5 +13,5 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data">
 
   <table class="display dataTableManage">
@@ -46,5 +46,5 @@
   </table>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <span tal:repeat="action view/actions"
           tal:omit-tag="">
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentspage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentspage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/paymentspage.pt	(revision 7459)
@@ -1,7 +1,4 @@
 <h2 tal:content="view/label">TITLE</h2>
 
-<table class="zebra">
-<thead>
-</thead>
 <table class="display dataTable">
   <thead>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/setpassword.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/setpassword.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/setpassword.pt	(revision 7459)
@@ -2,16 +2,20 @@
     tal:content="view/label">Label</h2>
 <form method="POST">
-  <table>
+  <table class="form-table">
     <tbody>
-      <tr><td>
-          <label for="reg_number">Registration Number:
-          </label></td> <td>
+      <tr>
+      <td>
+          Registration Number:
+      </td>
+      <td>
           <input name="reg_number" type="text" size="15" maxlength="15"
                  value="" tal:attributes="value view/reg_number"/>
-      </td></tr>
+      </td>
+      </tr>
       <tr>
         <td>
-          <label for="ac_series">Access Code:
-          </label></td> <td>
+          Access Code:
+        </td>
+        <td>
           <span tal:replace="view/ac_prefix">PIN Prefix
           </span> -
@@ -23,5 +27,5 @@
       <tr>
         <td colspan="2">
-        <input type="submit" name="SUBMIT"
+        <input type="submit" name="SUBMIT" class="btn primary"
                value="Show Student Id and set password" /> </td>
       </tr>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studentpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studentpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studentpage.pt	(revision 7459)
@@ -3,5 +3,5 @@
     tal:content="view/label">Label</h2>
 
-<table class="zebra">
+<table class="form-table">
   <tbody>
     <tal:block repeat="widget view/widgets">
@@ -17,5 +17,5 @@
   </tbody>
   <tfoot>
-    <tr class="controls">
+    <tr>
       <td colspan="2" class="align-right">
         <input tal:repeat="action view/actions"
@@ -24,5 +24,4 @@
     </tr>
   </tfoot>
-
 </table>
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursemanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursemanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursemanagepage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,100 +13,95 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data"> 
 
-<div id="tabs">
-<ul>
-  <li><a href="#tab-1"><span>Study Course Data</span></a></li>
-  <li><a href="#tab-2"><span>Study Levels</span></a></li>
-</ul>
-   
-<div id="tab-1">        
-  <table class="zebra">
-  <tbody>
-  <tal:block repeat="widget view/widgets">
-    <tr>
-      <td class="label">
-        <label tal:attributes="for widget/name">
-          <span class="required" tal:condition="widget/required">*</span>
-          <span i18n:translate="" tal:content="widget/label">label</span>:
-        </label>
-      </td>
-      <td class="field">
-        <span class="widget" tal:content="structure widget">
-          <input type="text" />
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active"><a href="#tab-1"><span>Study Course Data</span></a></li>
+    <li><a href="#tab-2"><span>Study Levels</span></a></li>
+  </ul>
+
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
+      <tbody>
+      <tal:block repeat="widget view/widgets">
+        <tr>
+          <td class="fieldname">
+            <span class="required" tal:condition="widget/required">*</span>
+            <span i18n:translate="" tal:content="widget/label">label</span>:
+          </td>
+          <td>
+            <span tal:content="structure widget">
+              <input type="text" />
+            </span>
+            <tal:error tal:condition="widget/error">
+              <span tal:replace="structure widget/error">error</span>
+            </tal:error>
+            <tal:hint tal:condition="widget/hint">
+              <span tal:content="structure widget/hint">hint</span>
+            </tal:hint>
+          </td>
+        </tr>
+      </tal:block>
+      </tbody>
+      </table>
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions"
+              tal:omit-tag="">
+          <input tal:condition="python:action.label in view.taboneactions"
+                 tal:replace="structure action/render"/>
         </span>
-        <tal:error tal:condition="widget/error">
-          <span tal:replace="structure widget/error">error</span>
-        </tal:error>
-        <tal:hint tal:condition="widget/hint">
-          <span class="hint" tal:content="structure widget/hint">hint</span>
-        </tal:hint>
-      </td>
-    </tr>
-  </tal:block>
-  </tbody>
-  </table>
-  <div class="actionButtons" tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.taboneactions"
-             tal:replace="structure action/render"/>
-    </span>
+      </div>
+    </div>
+
+    <div id="tab-2">
+      <h3>Study Levels (Course Lists)</h3>
+      <table class="display dataTableManage">
+        <thead>
+          <tr>
+            <th>&nbsp;</th><th>Level Code</th><th>Level Title</th>
+          </tr>
+        </thead>
+        <tbody>
+          <tr tal:repeat="cl context/values">
+             <td>
+              <input type="checkbox"
+        		 name="val_id"
+        		 tal:attributes="value cl/__name__" />
+            </td>
+            <td> <a tal:attributes="href cl/__name__">
+              <span tal:content="cl/level">CODE</span></a>
+            </td>
+            <td>
+              <span tal:content="cl/level_title">TITLE</span>
+            </td>
+          </tr>
+        </tbody>
+      </table>
+
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions"
+              tal:omit-tag="">
+          <input tal:condition="python:action.label in view.tabtwoactions"
+                 tal:replace="structure action/render"/>
+        </span>
+      </div>
+      <br /><br /><br />
+      <div>
+        <span tal:condition="view/availableActions">
+          <span tal:repeat="action view/actions"
+                tal:omit-tag="">
+            <input tal:condition="python:action.label in view.tabthreeactions"
+                   tal:replace="structure action/render"/>
+          </span>
+        </span>
+        <select id="addlevel" name="addlevel">
+          <option tal:attributes="value level/code" tal:repeat="level view/level_dict">
+            <span tal:replace="level/title">LEVELTITLE
+          </span>
+          </option>
+        </select>
+      </div>
+    </div>
   </div>
-</div>    
-    
-<div id="tab-2">
-  <h3>Study Levels (Course Lists)</h3>
-  <table class="display dataTableManage">
-    <thead>
-      <tr>
-        <th>&nbsp;</th><th>Level Code</th><th>Level Title</th>
-      </tr>
-    </thead>
-    <tbody>
-      <tr tal:repeat="cl context/values">
-         <td>
-          <input type="checkbox"
-    		 name="val_id"
-    		 tal:attributes="value cl/__name__" />
-        </td>
-        <td> <a tal:attributes="href cl/__name__">
-          <span tal:content="cl/level">CODE</span></a>
-        </td>
-        <td>
-          <span tal:content="cl/level_title">TITLE</span>
-        </td>
-      </tr>
-    </tbody>
-  </table>
-
-  <div class="actionButtons" tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.tabtwoactions"
-             tal:replace="structure action/render"/>
-    </span>
-  </div>
-  <br /><br /><br />
-  <div>
-    <span class="actionButtons" tal:condition="view/availableActions">
-      <span tal:repeat="action view/actions"
-            tal:omit-tag="">
-        <input tal:condition="python:action.label in view.tabthreeactions"
-               tal:replace="structure action/render"/>
-      </span>
-    </span>
-    <select id="addlevel" name="addlevel">
-      <option tal:attributes="value level/code" tal:repeat="level view/level_dict">
-        <span tal:replace="level/title">LEVELTITLE
-      </span>
-      </option>
-    </select>
-  </div>
-
-
-
-</div>
-</div>
 </form>  
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studycoursepage.pt	(revision 7459)
@@ -1,5 +1,5 @@
 <h2 tal:content="view/label">TITLE</h2>
 
-<table class="zebra">
+<table class="form-table">
 <thead>
 </thead>
@@ -7,11 +7,8 @@
   <tal:block repeat="widget view/widgets">
     <tr>
-      <td>
-        <label tal:attributes="for widget/name">
-          <span i18n:translate=""
-                         tal:content="widget/label">label</span>:
-        </label>
+      <td class="filedname">
+        <span i18n:translate="" tal:content="widget/label">label</span>:
       </td>
-      <td class="field" tal:on-error="default">
+      <td tal:on-error="default">
         <div class="widget" tal:content="structure widget">
           <input type="text" />
@@ -22,7 +19,5 @@
     <tr>
       <td>
-        <label>
           Study Mode:
-        </label>
       </td>
       <td class="field">
@@ -34,7 +29,5 @@
     <tr tal:condition="python: view.department is not None">
       <td>
-        <label>
           Department:
-        </label>
       </td>
       <td class="field">
@@ -47,7 +40,5 @@
     <tr tal:condition="python: view.faculty is not None">
       <td>
-        <label>
           Faculty:
-        </label>
       </td>
       <td class="field">
@@ -64,5 +55,5 @@
 
 
-<table class="zebra">
+<table>
   <thead>
     <tr>
@@ -72,5 +63,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="value context/values">
+    <tr class="gradeC" tal:repeat="value context/values">
       <td> <a tal:attributes="href value/__name__">
       <span tal:content="value/level">CODE</span></a></td>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveladdpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveladdpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveladdpage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,5 +13,5 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data"> 
 
   <p>Text to explain course registration procedure.</p>
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveleditpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveleditpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studyleveleditpage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,5 +13,5 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data"> 
 
   <h3>Course Tickets (Total Credits: <span tal:replace="view/total_credits">TOTAL</span>)</h3>
@@ -30,5 +30,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="value context/values">
+    <tr tal:repeat="value context/values" class="gradeC">
        <td>
         <input type="checkbox" name="val_id"
@@ -49,5 +49,5 @@
   </table>
 
-  <div class="actionButtons" tal:condition="view/availableActions">
+  <div tal:condition="view/availableActions">
     <span tal:repeat="action view/actions"
           tal:omit-tag="">
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelmanagepage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelmanagepage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelmanagepage.pt	(revision 7459)
@@ -3,5 +3,5 @@
 tal:content="view/label">Label</h2>
 
-<div class="form-status"
+<div class="alert-message error"
     tal:define="status view/status"
     tal:condition="status">
@@ -13,95 +13,93 @@
 
 <form action="." tal:attributes="action request/URL" method="POST"
-      class="edit-form" enctype="multipart/form-data"> 
+      enctype="multipart/form-data"> 
 
-<div id="tabs">
-<ul>
-  <li><a href="#tab-1"><span>Study Level Data</span></a></li>
-  <li><a href="#tab-2"><span>Course Tickets</span></a></li>
-</ul>
-   
-<div id="tab-1">        
-  <table class="zebra">
-  <tbody>
-  <tal:block repeat="widget view/widgets">
-    <tr>
-      <td class="label">
-        <label tal:attributes="for widget/name">
-          <span class="required" tal:condition="widget/required">*</span>
-          <span i18n:translate="" tal:content="widget/label">label</span>:
-        </label>
-      </td>
-      <td class="field">
-        <span class="widget" tal:content="structure widget">
-          <input type="text" />
+  <ul class="tabs" data-tabs="tabs">
+    <li class="active"><a href="#tab-1"><span>Study Level Data</span></a></li>
+    <li><a href="#tab-2"><span>Course Tickets</span></a></li>
+  </ul>
+
+  <div class="tab-content">
+    <div id="tab-1" class="active">
+      <table class="form-table">
+      <tbody>
+      <tal:block repeat="widget view/widgets">
+        <tr>
+          <td class="fieldname">
+            <span class="required" tal:condition="widget/required">*</span>
+            <span i18n:translate="" tal:content="widget/label">label</span>:
+          </td>
+          <td>
+            <span tal:content="structure widget">
+              <input type="text" />
+            </span>
+            <tal:error tal:condition="widget/error">
+              <span tal:replace="structure widget/error">error</span>
+            </tal:error>
+            <tal:hint tal:condition="widget/hint">
+              <span tal:content="structure widget/hint">hint</span>
+            </tal:hint>
+          </td>
+        </tr>
+      </tal:block>
+      </tbody>
+      </table>
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions"
+              tal:omit-tag="">
+          <input tal:condition="python:action.label in view.taboneactions"
+                 tal:replace="structure action/render"/>
         </span>
-        <tal:error tal:condition="widget/error">
-          <span tal:replace="structure widget/error">error</span>
-        </tal:error>
-        <tal:hint tal:condition="widget/hint">
-          <span class="hint" tal:content="structure widget/hint">hint</span>
-        </tal:hint>
-      </td>
-    </tr>
-  </tal:block>
-  </tbody>
-  </table>
-  <div class="actionButtons" tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.taboneactions"
-             tal:replace="structure action/render"/>
-    </span>
+      </div>
+    </div>
+
+    <div id="tab-2">
+      <h3>Course Tickets</h3>
+      <table class="display dataTableManage">
+      <thead>
+        <tr>
+          <th>&nbsp;</th>
+          <th>Sem.</th>
+          <th>Code</th>
+          <th>Title</th>
+          <th>Department</th>
+          <th>Faculty</th>
+          <th>Credits</th>
+          <th>Mandatory</th>
+          <th>Score</th>
+          <th>Auto</th>
+        </tr>
+      </thead>
+      <tbody>
+        <tr tal:repeat="value context/values" class="gradeC">
+          <td>
+            <input type="checkbox" name="val_id"
+      		  tal:attributes="value value/__name__" />
+          </td>
+          <td tal:content="value/semester">SEMESTER</td>
+          <td> <a tal:attributes="href value/__name__">
+          <span tal:content="value/code">CODE</span>
+          </a></td>
+          <td tal:content="value/title">TITLE</td>
+          <td tal:content="value/department">DEPARTMENT</td>
+          <td tal:content="value/faculty">FACULTY</td>
+          <td tal:content="value/credits">CREDITS</td>
+          <td tal:content="value/core_or_elective">MANDATORY</td>
+          <td tal:content="value/score">SCORE</td>
+          <td tal:content="value/automatic">AUTO</td>
+        </tr>
+      </tbody>
+      </table>
+
+      <div tal:condition="view/availableActions">
+        <span tal:repeat="action view/actions"
+              tal:omit-tag="">
+          <input tal:condition="python:action.label in view.tabtwoactions"
+                 tal:replace="structure action/render"/>
+        </span>
+      </div>
+
+    </div>
   </div>
-</div>    
-    
-<div id="tab-2">
-  <h3>Course Tickets</h3>
-  <table class="display dataTableManage">
-  <thead>
-    <tr>
-      <th>&nbsp;</th>
-      <th>Sem.</th>
-      <th>Code</th>
-      <th>Title</th>
-      <th>Department</th>
-      <th>Faculty</th>
-      <th>Credits</th>
-      <th>Mandatory</th>
-      <th>Score</th>
-      <th>Auto</th>
-    </tr>
-  </thead>
-  <tbody>
-    <tr tal:repeat="value context/values">
-      <td>
-        <input type="checkbox" name="val_id"
-  		  tal:attributes="value value/__name__" />
-      </td>
-      <td tal:content="value/semester">SEMESTER</td>
-      <td> <a tal:attributes="href value/__name__">
-      <span tal:content="value/code">CODE</span>
-      </a></td>
-      <td tal:content="value/title">TITLE</td>
-      <td tal:content="value/department">DEPARTMENT</td>
-      <td tal:content="value/faculty">FACULTY</td>
-      <td tal:content="value/credits">CREDITS</td>
-      <td tal:content="value/core_or_elective">MANDATORY</td>
-      <td tal:content="value/score">SCORE</td>
-      <td tal:content="value/automatic">AUTO</td>
-    </tr>
-  </tbody>
-  </table>
-
-  <div class="actionButtons" tal:condition="view/availableActions">
-    <span tal:repeat="action view/actions"
-          tal:omit-tag="">
-      <input tal:condition="python:action.label in view.tabtwoactions"
-             tal:replace="structure action/render"/>
-    </span>
-  </div>
-
-</div>
-</div>
 </form>  
 
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelpage.pt
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelpage.pt	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/browser_templates/studylevelpage.pt	(revision 7459)
@@ -1,5 +1,5 @@
 <h2 tal:content="view/label">TITLE</h2>
 
-<table class="zebra">
+<table class="form-table">
 <thead>
 </thead>
@@ -7,11 +7,8 @@
   <tal:block repeat="widget view/widgets">
     <tr>
-      <td>
-        <label tal:attributes="for widget/name">
-          <span i18n:translate=""
-                         tal:content="widget/label">label</span>:
-        </label>
+      <td class="fieldname">
+        <span i18n:translate="" tal:content="widget/label">label</span>:
       </td>
-      <td class="field" tal:on-error="default">
+      <td tal:on-error="default">
         <div class="widget" tal:content="structure widget">
           <input type="text" />
@@ -22,5 +19,5 @@
   <tr>
     <td>
-      <label>Total Credits:</label>
+      Total Credits:
     </td>
     <td>
@@ -33,5 +30,5 @@
 <h3>Course Tickets</h3>
 
-<table class="display dataTable" >
+<table class="display dataTable">
   <thead>
     <tr>
@@ -48,5 +45,5 @@
   </thead>
   <tbody>
-    <tr tal:repeat="value context/values">
+    <tr tal:repeat="value context/values" class="gradeC">
       <td tal:content="value/semester">SEMESTER</td>
       <td> <a tal:attributes="href value/__name__">
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/tests/test_browser.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/tests/test_browser.py	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/tests/test_browser.py	(revision 7459)
@@ -807,5 +807,5 @@
         self.browser.getLink("Clear student").click()
         self.assertTrue('Student has been cleared' in self.browser.contents)
-        self.assertTrue('State: <span>cleared</span>' in self.browser.contents)
+        self.assertTrue('cleared' in self.browser.contents)
         self.browser.getLink("Reject clearance").click()
         self.assertTrue('Clearance has been annulled' in self.browser.contents)
@@ -814,6 +814,5 @@
         self.assertEqual(self.browser.url, self.student_path +
             '/contactstudent?subject=%s' % urlmessage)
-        self.assertTrue('State: <span>clearance started</span>'
-            in self.browser.contents)
+        self.assertTrue('clearance started' in self.browser.contents)
         IWorkflowInfo(self.student).fireTransition('request_clearance')
         self.browser.open(self.clearance_student_path)
@@ -821,6 +820,5 @@
         self.assertTrue('Clearance request has been rejected'
             in self.browser.contents)
-        self.assertTrue('State: <span>clearance started</span>'
-            in self.browser.contents)
+        self.assertTrue('clearance started' in self.browser.contents)
         # CO does now also see the contact form and can send a message
         self.browser.getControl(name="form.subject").value = 'Important subject'
@@ -917,5 +915,5 @@
         self.browser.getLink("Validate courses").click()
         self.assertTrue('Course list has been validated' in self.browser.contents)
-        self.assertTrue('State: <span>courses validated</span>' in self.browser.contents)
+        self.assertTrue('courses validated' in self.browser.contents)
         self.browser.getLink("Reject courses").click()
         self.assertTrue('Course list request has been annulled'
@@ -924,6 +922,5 @@
         self.assertEqual(self.browser.url, self.student_path +
             '/contactstudent?subject=%s' % urlmessage)
-        self.assertTrue('State: <span>school fee paid</span>'
-            in self.browser.contents)
+        self.assertTrue('school fee paid' in self.browser.contents)
         IWorkflowInfo(self.student).fireTransition('register_courses')
         self.browser.open(L110_student_path)
@@ -931,6 +928,5 @@
         self.assertTrue('Course list request has been rejected'
             in self.browser.contents)
-        self.assertTrue('State: <span>school fee paid</span>'
-            in self.browser.contents)
+        self.assertTrue('school fee paid' in self.browser.contents)
         # CA does now see the contact form and can send a message
         self.browser.getControl(name="form.subject").value = 'Important subject'
@@ -977,5 +973,5 @@
         self.assertTrue('Password changed' in self.browser.contents)
         # We are still logged in. Changing the password hasn't thrown us out.
-        self.browser.getLink("My Data").click()
+        self.browser.getLink("Base Data").click()
         self.assertEqual(self.browser.url, self.student_path)
         # We can logout
Index: main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py
===================================================================
--- main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py	(revision 7433)
+++ main/waeup.sirp/trunk/src/waeup/sirp/students/viewlets.py	(revision 7459)
@@ -57,14 +57,9 @@
     def render(self):
         url = self.view.url(self.context.getStudent(), self.link)
-        return u'<div class="portlet"><a href="%s">%s</a></div>' % (
+        return u'<li><a href="%s">%s</a></li>' % (
                 url, self.text)
 
-class StudentManageBaseLink(StudentManageLink):
-    grok.order(1)
-    link = 'index'
-    text = u'Base Data'
-
 class StudentManageApplicationLink(StudentManageLink):
-    grok.order(2)
+    grok.order(1)
     link = 'application_slip'
     text = u'Application Slip'
@@ -75,7 +70,12 @@
         if slip:
             url = self.view.url(self.context,self.link)
-            return u'<div class="portlet"><a href="%s">%s</a></div>' % (
+            return u'<li><a href="%s">%s</a></li>' % (
                     url, self.text)
         return ''
+
+class StudentManageBaseLink(StudentManageLink):
+    grok.order(2)
+    link = 'index'
+    text = u'Base Data'
 
 class StudentManageClearanceLink(StudentManageLink):
@@ -104,80 +104,7 @@
     grok.require('waeup.handleAccommodation')
     link = 'accommodation'
-    text = u'Accommodation Data'
+    text = u'Accommodation'
 
 class StudentManageHistoryLink(StudentManageLink):
-    grok.order(8)
-    link = 'history'
-    text = u'History'
-
-
-class StudentMenu(grok.ViewletManager):
-    grok.name('top_student')
-
-class StudentLink(PlainActionButton):
-    """A link displayed in the student box which shows up for StudentNavigation
-    objects.
-
-    """
-    grok.baseclass()
-    grok.viewletmanager(StudentMenu)
-    grok.context(ISIRPObject)
-    grok.view(Interface)
-    grok.order(5)
-    grok.require('waeup.viewStudent')
-
-    link = 'index'
-    text = u'Base Data'
-
-    @property
-    def target_url(self):
-        """Get a URL to the target...
-        """
-        return self.view.url(self.context.getStudent(), self.link)
-
-class StudentBaseLink(StudentLink):
-    grok.order(1)
-    link = 'index'
-    text = u'Base Data'
-
-class ApplicationSlipLink(StudentLink):
-    grok.order(2)
-    link = 'application_slip'
-    text = u'Application Slip'
-
-    @property
-    def target_url(self):
-        slip = getUtility(IExtFileStore).getFileByContext(
-            self.context.getStudent(), attr=self.link)
-        if slip:
-            return self.view.url(self.context,self.link)
-        return
-
-class StudentClearanceLink(StudentLink):
-    grok.order(3)
-    link = 'view_clearance'
-    text = u'Clearance Data'
-
-class StudentPersonalLink(StudentLink):
-    grok.order(4)
-    link = 'view_personal'
-    text = u'Personal Data'
-
-class StudentStudyCourseLink(StudentLink):
-    grok.order(5)
-    link = 'studycourse'
-    text = u'Study Course'
-
-class StudentPaymentsLink(StudentLink):
-    grok.order(6)
-    link = 'payments'
-    text = u'Payments'
-
-class StudentAccommodationLink(StudentLink):
-    grok.order(7)
-    link = 'accommodation'
-    text = u'Accommodation'
-
-class StudentHistoryLink(StudentLink):
     grok.order(8)
     link = 'history'
@@ -227,15 +154,38 @@
 
 class MyStudentDataTab(PrimaryStudentNavTab):
     """MyData-tab in primary navigation.
     """
     grok.order(3)
     grok.require('waeup.viewMyStudentDataTab')
+    grok.template('mydatadropdowntabs')
     pnav = 4
     tab_title = u'My Data'
 
     @property
-    def link_target(self):
-        rel_link = '/students/%s' % self.request.principal.id
-        return self.view.application_url() + rel_link
+    def active(self):
+        view_pnav = getattr(self.view, 'pnav', 0)
+        if view_pnav == self.pnav:
+            return 'active dropdown'
+        return 'dropdown'
+
+    @property
+    def targets(self):
+        student_url = self.view.application_url() + (
+            '/students/%s' % self.request.principal.id)
+        #app_slip = getUtility(IExtFileStore).getFileByContext(
+        #    self.context.getStudent(), 'application_slip')
+        targets = []
+        #if app_slip:
+        #    targets = [{'url':student_url + '/application_slip', 'title':'Application Slip'},]
+        targets += [
+            {'url':student_url, 'title':'Base Data'},
+            {'url':student_url + '/view_clearance', 'title':'Clearance Data'},
+            {'url':student_url + '/view_personal', 'title':'Personal Data'},
+            {'url':student_url + '/studycourse', 'title':'Study Course'},
+            {'url':student_url + '/payments', 'title':'Payments'},
+            {'url':student_url + '/accommodation', 'title':'Accommodation Data'},
+            {'url':student_url + '/history', 'title':'History'},
+            ]
+        return targets
 
 def handle_file_delete(context, view, download_name):
@@ -227,15 +154,38 @@
 
 class MyStudentDataTab(PrimaryStudentNavTab):
-    """MyData-tab in primary navigation.
+    """MyData dropdown tab in primary navigation.
     """
     grok.order(3)
